@@ -10,5 +10,7 @@ from .complete_all_tasks import complete_all_tasks
 from .acall import acall
 from .async_on_stop import AsyncOnStop
 from .async_on_start import AsyncOnStart
+from .await_dict_values import await_dict_values
 from .recursive import do_recursive
-from .dummy_async_context_manager import DummyAsyncContextManager
\ No newline at end of file
+from .dummy_async_context_manager import DummyAsyncContextManager
+from .strict_gather import strict_gather
\ No newline at end of file
